hs-opentelemetry-api
Safe HaskellNone
LanguageHaskell2010

OpenTelemetry.Exporter.Metric

Description

Push metric exporter interface (specificationmetricssdk.md, MetricExporter).

Synopsis

Documentation

data MetricExport Source #

One exported metric (all points share nameunitdescription/scope).

Since: 0.0.1.0

Instances

Instances details
Generic MetricExport Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Associated Types

type Rep MetricExport 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep MetricExport = D1 ('MetaData "MetricExport" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) ((C1 ('MetaCons "MetricExportSum" 'PrefixI 'True) (((S1 ('MetaSel ('Just "mesName") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text) :*: S1 ('MetaSel ('Just "mesDescription") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text)) :*: (S1 ('MetaSel ('Just "mesUnit") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text) :*: S1 ('MetaSel ('Just "mesScope") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 InstrumentationLibrary))) :*: ((S1 ('MetaSel ('Just "mesMonotonic") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Bool) :*: S1 ('MetaSel ('Just "mesIsInt") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Bool)) :*: (S1 ('MetaSel ('Just "mesAggregationTemporality") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 AggregationTemporality) :*: S1 ('MetaSel ('Just "mesSumPoints") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector SumDataPoint))))) :+: C1 ('MetaCons "MetricExportHistogram" 'PrefixI 'True) ((S1 ('MetaSel ('Just "mehName") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text) :*: (S1 ('MetaSel ('Just "mehDescription") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text) :*: S1 ('MetaSel ('Just "mehUnit") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text))) :*: (S1 ('MetaSel ('Just "mehScope") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 InstrumentationLibrary) :*: (S1 ('MetaSel ('Just "mehAggregationTemporality") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 AggregationTemporality) :*: S1 ('MetaSel ('Just "mehPoints") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector HistogramDataPoint)))))) :+: (C1 ('MetaCons "MetricExportExponentialHistogram" 'PrefixI 'True) ((S1 ('MetaSel ('Just "meehName") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text) :*: (S1 ('MetaSel ('Just "meehDescription") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text) :*: S1 ('MetaSel ('Just "meehUnit") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text))) :*: (S1 ('MetaSel ('Just "meehScope") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 InstrumentationLibrary) :*: (S1 ('MetaSel ('Just "meehAggregationTemporality") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 AggregationTemporality) :*: S1 ('MetaSel ('Just "meehPoints") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector ExponentialHistogramDataPoint))))) :+: C1 ('MetaCons "MetricExportGauge" 'PrefixI 'True) ((S1 ('MetaSel ('Just "megName") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text) :*: (S1 ('MetaSel ('Just "megDescription") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text) :*: S1 ('MetaSel ('Just "megUnit") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text))) :*: (S1 ('MetaSel ('Just "megScope") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 InstrumentationLibrary) :*: (S1 ('MetaSel ('Just "megIsInt") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Bool) :*: S1 ('MetaSel ('Just "megGaugePoints") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector GaugeDataPoint)))))))
Show MetricExport Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Eq MetricExport Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep MetricExport Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep MetricExport = D1 ('MetaData "MetricExport" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) ((C1 ('MetaCons "MetricExportSum" 'PrefixI 'True) (((S1 ('MetaSel ('Just "mesName") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text) :*: S1 ('MetaSel ('Just "mesDescription") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text)) :*: (S1 ('MetaSel ('Just "mesUnit") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text) :*: S1 ('MetaSel ('Just "mesScope") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 InstrumentationLibrary))) :*: ((S1 ('MetaSel ('Just "mesMonotonic") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Bool) :*: S1 ('MetaSel ('Just "mesIsInt") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Bool)) :*: (S1 ('MetaSel ('Just "mesAggregationTemporality") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 AggregationTemporality) :*: S1 ('MetaSel ('Just "mesSumPoints") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector SumDataPoint))))) :+: C1 ('MetaCons "MetricExportHistogram" 'PrefixI 'True) ((S1 ('MetaSel ('Just "mehName") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text) :*: (S1 ('MetaSel ('Just "mehDescription") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text) :*: S1 ('MetaSel ('Just "mehUnit") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text))) :*: (S1 ('MetaSel ('Just "mehScope") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 InstrumentationLibrary) :*: (S1 ('MetaSel ('Just "mehAggregationTemporality") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 AggregationTemporality) :*: S1 ('MetaSel ('Just "mehPoints") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector HistogramDataPoint)))))) :+: (C1 ('MetaCons "MetricExportExponentialHistogram" 'PrefixI 'True) ((S1 ('MetaSel ('Just "meehName") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text) :*: (S1 ('MetaSel ('Just "meehDescription") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text) :*: S1 ('MetaSel ('Just "meehUnit") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text))) :*: (S1 ('MetaSel ('Just "meehScope") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 InstrumentationLibrary) :*: (S1 ('MetaSel ('Just "meehAggregationTemporality") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 AggregationTemporality) :*: S1 ('MetaSel ('Just "meehPoints") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector ExponentialHistogramDataPoint))))) :+: C1 ('MetaCons "MetricExportGauge" 'PrefixI 'True) ((S1 ('MetaSel ('Just "megName") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text) :*: (S1 ('MetaSel ('Just "megDescription") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text) :*: S1 ('MetaSel ('Just "megUnit") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Text))) :*: (S1 ('MetaSel ('Just "megScope") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 InstrumentationLibrary) :*: (S1 ('MetaSel ('Just "megIsInt") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Bool) :*: S1 ('MetaSel ('Just "megGaugePoints") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector GaugeDataPoint)))))))

data ResourceMetricsExport Source #

Since: 0.0.1.0

Instances

Instances details
Generic ResourceMetricsExport Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Associated Types

type Rep ResourceMetricsExport 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep ResourceMetricsExport = D1 ('MetaData "ResourceMetricsExport" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "ResourceMetricsExport" 'PrefixI 'True) (S1 ('MetaSel ('Just "resourceMetricsResource") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 MaterializedResources) :*: S1 ('MetaSel ('Just "resourceMetricsScopes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector ScopeMetricsExport))))
Show ResourceMetricsExport Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Eq ResourceMetricsExport Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep ResourceMetricsExport Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep ResourceMetricsExport = D1 ('MetaData "ResourceMetricsExport" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "ResourceMetricsExport" 'PrefixI 'True) (S1 ('MetaSel ('Just "resourceMetricsResource") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 MaterializedResources) :*: S1 ('MetaSel ('Just "resourceMetricsScopes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector ScopeMetricsExport))))

data ScopeMetricsExport Source #

Since: 0.0.1.0

Instances

Instances details
Generic ScopeMetricsExport Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Associated Types

type Rep ScopeMetricsExport 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep ScopeMetricsExport = D1 ('MetaData "ScopeMetricsExport" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "ScopeMetricsExport" 'PrefixI 'True) (S1 ('MetaSel ('Just "scopeMetricsScope") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 InstrumentationLibrary) :*: S1 ('MetaSel ('Just "scopeMetricsExports") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector MetricExport))))
Show ScopeMetricsExport Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Eq ScopeMetricsExport Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep ScopeMetricsExport Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep ScopeMetricsExport = D1 ('MetaData "ScopeMetricsExport" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "ScopeMetricsExport" 'PrefixI 'True) (S1 ('MetaSel ('Just "scopeMetricsScope") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 InstrumentationLibrary) :*: S1 ('MetaSel ('Just "scopeMetricsExports") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector MetricExport))))

data AggregationTemporality Source #

Export-time aggregation temporality (maps to OTLP AggregationTemporality).

Since: 0.0.1.0

Instances

Instances details
Generic AggregationTemporality Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Associated Types

type Rep AggregationTemporality 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep AggregationTemporality = D1 ('MetaData "AggregationTemporality" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "AggregationDelta" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "AggregationCumulative" 'PrefixI 'False) (U1 :: Type -> Type))
Show AggregationTemporality Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Eq AggregationTemporality Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep AggregationTemporality Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep AggregationTemporality = D1 ('MetaData "AggregationTemporality" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "AggregationDelta" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "AggregationCumulative" 'PrefixI 'False) (U1 :: Type -> Type))

data NumberValue Source #

A numeric metric value, either integral or floating-point. Uses UNPACK to avoid the extra indirection that Either Int64 Double incurs.

Since: 0.0.1.0

Instances

Instances details
Generic NumberValue Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Associated Types

type Rep NumberValue 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep NumberValue = D1 ('MetaData "NumberValue" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "IntNumber" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'SourceUnpack 'SourceStrict 'DecidedStrict) (Rec0 Int64)) :+: C1 ('MetaCons "DoubleNumber" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'SourceUnpack 'SourceStrict 'DecidedStrict) (Rec0 Double)))
Show NumberValue Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Eq NumberValue Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep NumberValue Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep NumberValue = D1 ('MetaData "NumberValue" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "IntNumber" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'SourceUnpack 'SourceStrict 'DecidedStrict) (Rec0 Int64)) :+: C1 ('MetaCons "DoubleNumber" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'SourceUnpack 'SourceStrict 'DecidedStrict) (Rec0 Double)))

data OptionalDouble Source #

An optional Double, using UNPACK to avoid the extra box that Maybe Double incurs. 2 words for SomeDouble vs 4 for Just (D# x).

Since: 0.0.1.0

Constructors

NoDouble 
SomeDouble !Double 

Instances

Instances details
Generic OptionalDouble Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Associated Types

type Rep OptionalDouble 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep OptionalDouble = D1 ('MetaData "OptionalDouble" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "NoDouble" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "SomeDouble" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'SourceUnpack 'SourceStrict 'DecidedStrict) (Rec0 Double)))
Show OptionalDouble Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Eq OptionalDouble Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep OptionalDouble Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep OptionalDouble = D1 ('MetaData "OptionalDouble" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "NoDouble" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "SomeDouble" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'SourceUnpack 'SourceStrict 'DecidedStrict) (Rec0 Double)))

toMaybeDouble :: OptionalDouble -> Maybe Double Source #

Convert to the standard Maybe Double (e.g. for OTLP export).

Since: 0.0.1.0

data MetricExemplar Source #

Exemplar (trace link + optional measurement) for OTLP Exemplar.

Since: 0.0.1.0

Instances

Instances details
Generic MetricExemplar Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Associated Types

type Rep MetricExemplar 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep MetricExemplar = D1 ('MetaData "MetricExemplar" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "MetricExemplar" 'PrefixI 'True) ((S1 ('MetaSel ('Just "metricExemplarTraceId") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 ByteString) :*: S1 ('MetaSel ('Just "metricExemplarSpanId") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 ByteString)) :*: (S1 ('MetaSel ('Just "metricExemplarTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: (S1 ('MetaSel ('Just "metricExemplarFilteredAttributes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Attributes) :*: S1 ('MetaSel ('Just "metricExemplarValue") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe NumberValue))))))
Show MetricExemplar Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Eq MetricExemplar Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep MetricExemplar Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep MetricExemplar = D1 ('MetaData "MetricExemplar" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "MetricExemplar" 'PrefixI 'True) ((S1 ('MetaSel ('Just "metricExemplarTraceId") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 ByteString) :*: S1 ('MetaSel ('Just "metricExemplarSpanId") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 ByteString)) :*: (S1 ('MetaSel ('Just "metricExemplarTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: (S1 ('MetaSel ('Just "metricExemplarFilteredAttributes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Attributes) :*: S1 ('MetaSel ('Just "metricExemplarValue") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe NumberValue))))))

data SumDataPoint Source #

One sum data point (cumulative or delta depending on reader temporality in SDK).

Since: 0.0.1.0

Instances

Instances details
Generic SumDataPoint Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Associated Types

type Rep SumDataPoint 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep SumDataPoint = D1 ('MetaData "SumDataPoint" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "SumDataPoint" 'PrefixI 'True) ((S1 ('MetaSel ('Just "sumDataPointStartTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: S1 ('MetaSel ('Just "sumDataPointTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64)) :*: (S1 ('MetaSel ('Just "sumDataPointValue") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 NumberValue) :*: (S1 ('MetaSel ('Just "sumDataPointAttributes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Attributes) :*: S1 ('MetaSel ('Just "sumDataPointExemplars") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector MetricExemplar))))))
Show SumDataPoint Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Eq SumDataPoint Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep SumDataPoint Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep SumDataPoint = D1 ('MetaData "SumDataPoint" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "SumDataPoint" 'PrefixI 'True) ((S1 ('MetaSel ('Just "sumDataPointStartTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: S1 ('MetaSel ('Just "sumDataPointTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64)) :*: (S1 ('MetaSel ('Just "sumDataPointValue") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 NumberValue) :*: (S1 ('MetaSel ('Just "sumDataPointAttributes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Attributes) :*: S1 ('MetaSel ('Just "sumDataPointExemplars") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector MetricExemplar))))))

data HistogramDataPoint Source #

Histogram bucket counts (explicit boundaries) + sum + count.

Since: 0.0.1.0

Instances

Instances details
Generic HistogramDataPoint Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Associated Types

type Rep HistogramDataPoint 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep HistogramDataPoint = D1 ('MetaData "HistogramDataPoint" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "HistogramDataPoint" 'PrefixI 'True) (((S1 ('MetaSel ('Just "histogramDataPointStartTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: S1 ('MetaSel ('Just "histogramDataPointTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64)) :*: (S1 ('MetaSel ('Just "histogramDataPointCount") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: (S1 ('MetaSel ('Just "histogramDataPointSum") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Double) :*: S1 ('MetaSel ('Just "histogramDataPointBucketCounts") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector Word64))))) :*: ((S1 ('MetaSel ('Just "histogramDataPointExplicitBounds") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector Double)) :*: S1 ('MetaSel ('Just "histogramDataPointAttributes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Attributes)) :*: (S1 ('MetaSel ('Just "histogramDataPointMin") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Double)) :*: (S1 ('MetaSel ('Just "histogramDataPointMax") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Double)) :*: S1 ('MetaSel ('Just "histogramDataPointExemplars") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector MetricExemplar)))))))
Show HistogramDataPoint Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Eq HistogramDataPoint Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep HistogramDataPoint Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep HistogramDataPoint = D1 ('MetaData "HistogramDataPoint" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "HistogramDataPoint" 'PrefixI 'True) (((S1 ('MetaSel ('Just "histogramDataPointStartTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: S1 ('MetaSel ('Just "histogramDataPointTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64)) :*: (S1 ('MetaSel ('Just "histogramDataPointCount") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: (S1 ('MetaSel ('Just "histogramDataPointSum") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Double) :*: S1 ('MetaSel ('Just "histogramDataPointBucketCounts") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector Word64))))) :*: ((S1 ('MetaSel ('Just "histogramDataPointExplicitBounds") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector Double)) :*: S1 ('MetaSel ('Just "histogramDataPointAttributes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Attributes)) :*: (S1 ('MetaSel ('Just "histogramDataPointMin") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Double)) :*: (S1 ('MetaSel ('Just "histogramDataPointMax") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Double)) :*: S1 ('MetaSel ('Just "histogramDataPointExemplars") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector MetricExemplar)))))))

data ExponentialHistogramDataPoint Source #

Exponential histogram data point (OTLP native exponential layout).

Since: 0.0.1.0

Instances

Instances details
Generic ExponentialHistogramDataPoint Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Associated Types

type Rep ExponentialHistogramDataPoint 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep ExponentialHistogramDataPoint = D1 ('MetaData "ExponentialHistogramDataPoint" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "ExponentialHistogramDataPoint" 'PrefixI 'True) (((S1 ('MetaSel ('Just "exponentialHistogramDataPointStartTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: (S1 ('MetaSel ('Just "exponentialHistogramDataPointTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointCount") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64))) :*: ((S1 ('MetaSel ('Just "exponentialHistogramDataPointSum") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Double)) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointScale") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Int32)) :*: (S1 ('MetaSel ('Just "exponentialHistogramDataPointZeroCount") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointPositiveOffset") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Int32)))) :*: (((S1 ('MetaSel ('Just "exponentialHistogramDataPointPositiveBucketCounts") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector Word64)) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointNegativeOffset") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Int32)) :*: (S1 ('MetaSel ('Just "exponentialHistogramDataPointNegativeBucketCounts") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector Word64)) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointAttributes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Attributes))) :*: ((S1 ('MetaSel ('Just "exponentialHistogramDataPointMin") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Double)) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointMax") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Double))) :*: (S1 ('MetaSel ('Just "exponentialHistogramDataPointExemplars") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector MetricExemplar)) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointZeroThreshold") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Double))))))
Show ExponentialHistogramDataPoint Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Eq ExponentialHistogramDataPoint Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep ExponentialHistogramDataPoint Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep ExponentialHistogramDataPoint = D1 ('MetaData "ExponentialHistogramDataPoint" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "ExponentialHistogramDataPoint" 'PrefixI 'True) (((S1 ('MetaSel ('Just "exponentialHistogramDataPointStartTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: (S1 ('MetaSel ('Just "exponentialHistogramDataPointTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointCount") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64))) :*: ((S1 ('MetaSel ('Just "exponentialHistogramDataPointSum") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Double)) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointScale") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Int32)) :*: (S1 ('MetaSel ('Just "exponentialHistogramDataPointZeroCount") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointPositiveOffset") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Int32)))) :*: (((S1 ('MetaSel ('Just "exponentialHistogramDataPointPositiveBucketCounts") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector Word64)) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointNegativeOffset") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Int32)) :*: (S1 ('MetaSel ('Just "exponentialHistogramDataPointNegativeBucketCounts") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector Word64)) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointAttributes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Attributes))) :*: ((S1 ('MetaSel ('Just "exponentialHistogramDataPointMin") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Double)) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointMax") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Double))) :*: (S1 ('MetaSel ('Just "exponentialHistogramDataPointExemplars") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector MetricExemplar)) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointZeroThreshold") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Double))))))

data GaugeDataPoint Source #

Last-value gauge point.

Since: 0.0.1.0

Instances

Instances details
Generic GaugeDataPoint Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Associated Types

type Rep GaugeDataPoint 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep GaugeDataPoint = D1 ('MetaData "GaugeDataPoint" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "GaugeDataPoint" 'PrefixI 'True) ((S1 ('MetaSel ('Just "gaugeDataPointStartTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: S1 ('MetaSel ('Just "gaugeDataPointTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64)) :*: (S1 ('MetaSel ('Just "gaugeDataPointValue") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 NumberValue) :*: (S1 ('MetaSel ('Just "gaugeDataPointAttributes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Attributes) :*: S1 ('MetaSel ('Just "gaugeDataPointExemplars") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector MetricExemplar))))))
Show GaugeDataPoint Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

Eq GaugeDataPoint Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep GaugeDataPoint Source # 
Instance details

Defined in OpenTelemetry.Internal.Metric.Export

type Rep GaugeDataPoint = D1 ('MetaData "GaugeDataPoint" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "GaugeDataPoint" 'PrefixI 'True) ((S1 ('MetaSel ('Just "gaugeDataPointStartTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: S1 ('MetaSel ('Just "gaugeDataPointTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64)) :*: (S1 ('MetaSel ('Just "gaugeDataPointValue") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 NumberValue) :*: (S1 ('MetaSel ('Just "gaugeDataPointAttributes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Attributes) :*: S1 ('MetaSel ('Just "gaugeDataPointExemplars") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector MetricExemplar))))))

filterAttributesByKeys :: Maybe (HashSet Text) -> Attributes -> Attributes Source #

When a view selects attribute keys, drop other keys at export time (series identity unchanged).

The HashSet should be pre-built at instrument creation time so that this function avoids allocating a new set on every data point.

Since: 0.0.1.0

complementAttributesByKeys :: Maybe (HashSet Text) -> Attributes -> Attributes Source #

Complement of filterAttributesByKeys: returns attributes whose keys are NOT in the export set. Used for exemplar filtered_attributes per spec  metrics/sdk.md Exemplar: "the set of attributes that were filtered out by the aggregator".

The HashSet should be pre-built at instrument creation time so that this function avoids allocating a new set on every data point.

Since: 0.0.1.0