hs-opentelemetry-api
Copyright(c) Ian Duncan 2021
LicenseBSD-3
MaintainerIan Duncan
Stabilityexperimental
Portabilitynon-portable (GHC extensions)
Safe HaskellNone
LanguageHaskell2010

OpenTelemetry.Resource.DeploymentEnvironment

Description

 
Synopsis

Documentation

newtype DeploymentEnvironment Source #

The software deployment.

This resource doesn't have a an automatic detector because deployment environments tend to have very different detection mechanisms for differing projects.

Since: 0.0.1.0

Constructors

DeploymentEnvironment 

Fields