hs-opentelemetry-api
Copyright(c) Ian Duncan 2021
LicenseBSD-3
MaintainerIan Duncan
Stabilityexperimental
Portabilitynon-portable (GHC extensions)
Safe HaskellNone
LanguageHaskell2010

OpenTelemetry.Resource.Kubernetes

Description

 
Synopsis

Documentation

data Cluster Source #

A Kubernetes Cluster.

Since: 0.0.1.0

Constructors

Cluster 

Fields

Instances

Instances details
Show Cluster Source # 
Instance details

Defined in OpenTelemetry.Resource.Kubernetes

ToResource Cluster Source # 
Instance details

Defined in OpenTelemetry.Resource.Kubernetes

data Node Source #

A Kubernetes Node.

Since: 0.0.1.0

Constructors

Node 

Instances

Instances details
Show Node Source # 
Instance details

Defined in OpenTelemetry.Resource.Kubernetes

Methods

showsPrec :: Int -> Node -> ShowS #

show :: Node -> String #

showList :: [Node] -> ShowS #

ToResource Node Source # 
Instance details

Defined in OpenTelemetry.Resource.Kubernetes

newtype Namespace Source #

Namespaces provide a scope for names. Names of objects need to be unique within a namespace, but not across namespaces.

Since: 0.0.1.0

Constructors

Namespace 

Fields

Instances

Instances details
Show Namespace Source # 
Instance details

Defined in OpenTelemetry.Resource.Kubernetes

ToResource Namespace Source # 
Instance details

Defined in OpenTelemetry.Resource.Kubernetes

data Pod Source #

The smallest and simplest Kubernetes object. A Pod represents a set of running containers on your cluster.

Since: 0.0.1.0

Constructors

Pod 

Fields

Instances

Instances details
Show Pod Source # 
Instance details

Defined in OpenTelemetry.Resource.Kubernetes

Methods

showsPrec :: Int -> Pod -> ShowS #

show :: Pod -> String #

showList :: [Pod] -> ShowS #

ToResource Pod Source # 
Instance details

Defined in OpenTelemetry.Resource.Kubernetes

data Container Source #

A container in a PodTemplate.

Since: 0.0.1.0

Constructors

Container 

Fields

  • containerName :: Maybe Text

    The name of the Container from Pod specification, must be unique within a Pod. Container runtime usually uses different globally unique name (container.name).

  • containerRestartCount :: Maybe Int

    Number of times the container was restarted. This attribute can be used to identify a particular container (running or stopped) within a container spec.

Instances

Instances details
ToResource Container Source # 
Instance details

Defined in OpenTelemetry.Resource.Kubernetes

data ReplicaSet Source #

A ReplicaSet’s purpose is to maintain a stable set of replica Pods running at any given time.

Since: 0.0.1.0

Instances

Instances details
ToResource ReplicaSet Source # 
Instance details

Defined in OpenTelemetry.Resource.Kubernetes

data Deployment Source #

An API object that manages a replicated application, typically by running Pods with no local state. Each replica is represented by a Pod, and the Pods are distributed among the nodes of a cluster.

Since: 0.0.1.0

Constructors

Deployment 

Fields

Instances

Instances details
ToResource Deployment Source # 
Instance details

Defined in OpenTelemetry.Resource.Kubernetes

data StatefulSet Source #

Manages the deployment and scaling of a set of Pods, and provides guarantees about the ordering and uniqueness of these Pods.

Since: 0.0.1.0

Constructors

StatefulSet 

Fields

Instances

Instances details
ToResource StatefulSet Source # 
Instance details

Defined in OpenTelemetry.Resource.Kubernetes

data DaemonSet Source #

A DaemonSet ensures that all (or some) Nodes run a copy of a Pod.

Since: 0.0.1.0

Constructors

DaemonSet 

Fields

Instances

Instances details
ToResource DaemonSet Source # 
Instance details

Defined in OpenTelemetry.Resource.Kubernetes

data Job Source #

A Job creates one or more Pods and ensures that a specified number of them successfully terminate.

Since: 0.0.1.0

Constructors

Job 

Fields

Instances

Instances details
ToResource Job Source # 
Instance details

Defined in OpenTelemetry.Resource.Kubernetes

data CronJob Source #

A CronJob creates Jobs on a repeating schedule.

Since: 0.0.1.0

Constructors

CronJob 

Fields

Instances

Instances details
ToResource CronJob Source # 
Instance details

Defined in OpenTelemetry.Resource.Kubernetes