| Copyright | (c) Ian Duncan 2021 |
|---|---|
| License | BSD-3 |
| Maintainer | Ian Duncan |
| Stability | experimental |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
OpenTelemetry.Resource.OperatingSystem
Description
In case of virtualized environments, this is the operating system as it is observed by the process, i.e., the virtualized guest rather than the underlying host.
Documentation
data OperatingSystem Source #
The operating system (OS) on which the process represented by this resource is running.
Since: 0.0.1.0
Constructors
| OperatingSystem | |||||||||||||||||||||||||
Fields
| |||||||||||||||||||||||||
Instances
| ToResource OperatingSystem Source # | |
Defined in OpenTelemetry.Resource.OperatingSystem Methods toResource :: OperatingSystem -> Resource Source # | |