| Copyright | (c) Ian Duncan 2021 |
|---|---|
| License | BSD-3 |
| Maintainer | Ian Duncan |
| Stability | experimental |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
OpenTelemetry.Attributes
Contents
Description
An Attribute is a key-value pair, which MUST have the following properties:
- The attribute key MUST be a non-null and non-empty string.
- The attribute value is either:
- A primitive type: string, boolean, double precision floating point (IEEE 754-1985) or signed 64 bit integer.
- An array of primitive type values. The array MUST be homogeneous, i.e., it MUST NOT contain values of different types. For protocols that do not natively support array values such values SHOULD be represented as JSON strings.
- Attribute values expressing a numerical value of zero, an empty string, or an empty array are considered meaningful and MUST be stored and passed on to processors / exporters.
Synopsis
- data Attributes
- emptyAttributes :: Attributes
- addAttribute :: ToAttribute a => AttributeLimits -> Attributes -> Text -> a -> Attributes
- addAttributeByKey :: ToAttribute a => AttributeLimits -> Attributes -> AttributeKey a -> a -> Attributes
- addAttributes :: ToAttribute a => AttributeLimits -> Attributes -> HashMap Text a -> Attributes
- lookupAttribute :: Attributes -> Text -> Maybe Attribute
- lookupAttributeByKey :: FromAttribute a => Attributes -> AttributeKey a -> Maybe a
- getAttributeMap :: Attributes -> AttributeMap
- getCount :: Attributes -> Int
- getDropped :: Attributes -> Int
- data Attribute
- class ToAttribute a where
- toAttribute :: a -> Attribute
- class FromAttribute a where
- fromAttribute :: Attribute -> Maybe a
- data PrimitiveAttribute
- class ToPrimitiveAttribute a where
- class FromPrimitiveAttribute a where
- type AttributeMap = HashMap Text Attribute
- newtype AttributeKey a = AttributeKey {}
- module OpenTelemetry.Attributes.Key
- data AttributeLimits = AttributeLimits {}
- defaultAttributeLimits :: AttributeLimits
- unsafeAttributesFromListIgnoringLimits :: [(Text, Attribute)] -> Attributes
- unsafeMergeAttributesIgnoringLimits :: Attributes -> Attributes -> Attributes
Documentation
data Attributes Source #
Instances
addAttribute :: ToAttribute a => AttributeLimits -> Attributes -> Text -> a -> Attributes Source #
addAttributeByKey :: ToAttribute a => AttributeLimits -> Attributes -> AttributeKey a -> a -> Attributes Source #
addAttributes :: ToAttribute a => AttributeLimits -> Attributes -> HashMap Text a -> Attributes Source #
lookupAttribute :: Attributes -> Text -> Maybe Attribute Source #
lookupAttributeByKey :: FromAttribute a => Attributes -> AttributeKey a -> Maybe a Source #
getCount :: Attributes -> Int Source #
getDropped :: Attributes -> Int Source #
An attribute represents user-provided metadata about a span, link, or event.
Telemetry tools may use this data to support high-cardinality querying, visualization in waterfall diagrams, trace sampling decisions, and more.
Constructors
| AttributeValue PrimitiveAttribute | An attribute representing a single primitive value |
| AttributeArray [PrimitiveAttribute] | An attribute representing an array of primitive values. All values in the array MUST be of the same primitive attribute type. |
Instances
| Data Attribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> Attribute -> c Attribute # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c Attribute # toConstr :: Attribute -> Constr # dataTypeOf :: Attribute -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c Attribute) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c Attribute) # gmapT :: (forall b. Data b => b -> b) -> Attribute -> Attribute # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> Attribute -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> Attribute -> r # gmapQ :: (forall d. Data d => d -> u) -> Attribute -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> Attribute -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> Attribute -> m Attribute # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> Attribute -> m Attribute # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> Attribute -> m Attribute # | |||||
| IsString Attribute Source # | Create a Since: 0.0.2.1 | ||||
Defined in OpenTelemetry.Attributes.Attribute Methods fromString :: String -> Attribute # | |||||
| Generic Attribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute Associated Types
| |||||
| Read Attribute Source # | |||||
| Show Attribute Source # | |||||
| Eq Attribute Source # | |||||
| Ord Attribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute | |||||
| Hashable Attribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute | |||||
| FromAttribute Attribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute | |||||
| ToAttribute Attribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute Methods toAttribute :: Attribute -> Attribute Source # | |||||
| Lift Attribute Source # | |||||
| type Rep Attribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute type Rep Attribute = D1 ('MetaData "Attribute" "OpenTelemetry.Attributes.Attribute" "hs-opentelemetry-api-0.3.0.0-6VLKmhDACLT6bB8qCOmjAb" 'False) (C1 ('MetaCons "AttributeValue" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 PrimitiveAttribute)) :+: C1 ('MetaCons "AttributeArray" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 [PrimitiveAttribute]))) | |||||
class ToAttribute a where Source #
Convert a Haskell value to an Attribute value.
For most values, you can define an instance of ToPrimitiveAttribute and use the default toAttribute implementation:
data Foo = Foo instance ToPrimitiveAttribute Foo where toPrimitiveAttribute Foo = TextAttribute Foo instance ToAttribute foo
Minimal complete definition
Nothing
Methods
toAttribute :: a -> Attribute Source #
default toAttribute :: ToPrimitiveAttribute a => a -> Attribute Source #
Instances
| ToAttribute Int64 Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods toAttribute :: Int64 -> Attribute Source # | |
| ToAttribute Attribute Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods toAttribute :: Attribute -> Attribute Source # | |
| ToAttribute PrimitiveAttribute Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods | |
| ToAttribute Text Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods toAttribute :: Text -> Attribute Source # | |
| ToAttribute Bool Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods toAttribute :: Bool -> Attribute Source # | |
| ToAttribute Double Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods toAttribute :: Double -> Attribute Source # | |
| ToAttribute Int Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods toAttribute :: Int -> Attribute Source # | |
| ToPrimitiveAttribute a => ToAttribute [a] Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods toAttribute :: [a] -> Attribute Source # | |
class FromAttribute a where Source #
Minimal complete definition
Nothing
Methods
fromAttribute :: Attribute -> Maybe a Source #
default fromAttribute :: FromPrimitiveAttribute a => Attribute -> Maybe a Source #
Instances
| FromAttribute Int64 Source # | |
Defined in OpenTelemetry.Attributes.Attribute | |
| FromAttribute Attribute Source # | |
Defined in OpenTelemetry.Attributes.Attribute | |
| FromAttribute PrimitiveAttribute Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods fromAttribute :: Attribute -> Maybe PrimitiveAttribute Source # | |
| FromAttribute Text Source # | |
Defined in OpenTelemetry.Attributes.Attribute | |
| FromAttribute Bool Source # | |
Defined in OpenTelemetry.Attributes.Attribute | |
| FromAttribute Double Source # | |
Defined in OpenTelemetry.Attributes.Attribute | |
| FromAttribute Int Source # | |
Defined in OpenTelemetry.Attributes.Attribute | |
| FromPrimitiveAttribute a => FromAttribute [a] Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods fromAttribute :: Attribute -> Maybe [a] Source # | |
data PrimitiveAttribute Source #
Constructors
| TextAttribute Text | |
| BoolAttribute Bool | |
| DoubleAttribute Double | |
| IntAttribute Int64 |
Instances
| Data PrimitiveAttribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> PrimitiveAttribute -> c PrimitiveAttribute # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c PrimitiveAttribute # toConstr :: PrimitiveAttribute -> Constr # dataTypeOf :: PrimitiveAttribute -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c PrimitiveAttribute) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c PrimitiveAttribute) # gmapT :: (forall b. Data b => b -> b) -> PrimitiveAttribute -> PrimitiveAttribute # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> PrimitiveAttribute -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> PrimitiveAttribute -> r # gmapQ :: (forall d. Data d => d -> u) -> PrimitiveAttribute -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> PrimitiveAttribute -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> PrimitiveAttribute -> m PrimitiveAttribute # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> PrimitiveAttribute -> m PrimitiveAttribute # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> PrimitiveAttribute -> m PrimitiveAttribute # | |||||
| IsString PrimitiveAttribute Source # | Create a Since: 0.0.2.1 | ||||
Defined in OpenTelemetry.Attributes.Attribute Methods fromString :: String -> PrimitiveAttribute # | |||||
| Generic PrimitiveAttribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute Associated Types
Methods from :: PrimitiveAttribute -> Rep PrimitiveAttribute x # to :: Rep PrimitiveAttribute x -> PrimitiveAttribute # | |||||
| Read PrimitiveAttribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute Methods readsPrec :: Int -> ReadS PrimitiveAttribute # readList :: ReadS [PrimitiveAttribute] # | |||||
| Show PrimitiveAttribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute Methods showsPrec :: Int -> PrimitiveAttribute -> ShowS # show :: PrimitiveAttribute -> String # showList :: [PrimitiveAttribute] -> ShowS # | |||||
| Eq PrimitiveAttribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute Methods (==) :: PrimitiveAttribute -> PrimitiveAttribute -> Bool # (/=) :: PrimitiveAttribute -> PrimitiveAttribute -> Bool # | |||||
| Ord PrimitiveAttribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute Methods compare :: PrimitiveAttribute -> PrimitiveAttribute -> Ordering # (<) :: PrimitiveAttribute -> PrimitiveAttribute -> Bool # (<=) :: PrimitiveAttribute -> PrimitiveAttribute -> Bool # (>) :: PrimitiveAttribute -> PrimitiveAttribute -> Bool # (>=) :: PrimitiveAttribute -> PrimitiveAttribute -> Bool # max :: PrimitiveAttribute -> PrimitiveAttribute -> PrimitiveAttribute # min :: PrimitiveAttribute -> PrimitiveAttribute -> PrimitiveAttribute # | |||||
| Hashable PrimitiveAttribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute | |||||
| FromAttribute PrimitiveAttribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute Methods fromAttribute :: Attribute -> Maybe PrimitiveAttribute Source # | |||||
| FromPrimitiveAttribute PrimitiveAttribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute Methods fromPrimitiveAttribute :: PrimitiveAttribute -> Maybe PrimitiveAttribute Source # | |||||
| ToAttribute PrimitiveAttribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute Methods | |||||
| ToPrimitiveAttribute PrimitiveAttribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute Methods toPrimitiveAttribute :: PrimitiveAttribute -> PrimitiveAttribute Source # | |||||
| Lift PrimitiveAttribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute Methods lift :: Quote m => PrimitiveAttribute -> m Exp # liftTyped :: forall (m :: Type -> Type). Quote m => PrimitiveAttribute -> Code m PrimitiveAttribute # | |||||
| type Rep PrimitiveAttribute Source # | |||||
Defined in OpenTelemetry.Attributes.Attribute type Rep PrimitiveAttribute = D1 ('MetaData "PrimitiveAttribute" "OpenTelemetry.Attributes.Attribute" "hs-opentelemetry-api-0.3.0.0-6VLKmhDACLT6bB8qCOmjAb" 'False) ((C1 ('MetaCons "TextAttribute" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 Text)) :+: C1 ('MetaCons "BoolAttribute" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 Bool))) :+: (C1 ('MetaCons "DoubleAttribute" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 Double)) :+: C1 ('MetaCons "IntAttribute" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 Int64)))) | |||||
class ToPrimitiveAttribute a where Source #
Convert a Haskell value to a PrimitiveAttribute value.
Methods
Instances
| ToPrimitiveAttribute Int64 Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods toPrimitiveAttribute :: Int64 -> PrimitiveAttribute Source # | |
| ToPrimitiveAttribute PrimitiveAttribute Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods toPrimitiveAttribute :: PrimitiveAttribute -> PrimitiveAttribute Source # | |
| ToPrimitiveAttribute Text Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods | |
| ToPrimitiveAttribute Bool Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods | |
| ToPrimitiveAttribute Double Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods toPrimitiveAttribute :: Double -> PrimitiveAttribute Source # | |
| ToPrimitiveAttribute Int Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods | |
class FromPrimitiveAttribute a where Source #
Methods
fromPrimitiveAttribute :: PrimitiveAttribute -> Maybe a Source #
Instances
| FromPrimitiveAttribute Int64 Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods fromPrimitiveAttribute :: PrimitiveAttribute -> Maybe Int64 Source # | |
| FromPrimitiveAttribute PrimitiveAttribute Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods fromPrimitiveAttribute :: PrimitiveAttribute -> Maybe PrimitiveAttribute Source # | |
| FromPrimitiveAttribute Text Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods fromPrimitiveAttribute :: PrimitiveAttribute -> Maybe Text Source # | |
| FromPrimitiveAttribute Bool Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods fromPrimitiveAttribute :: PrimitiveAttribute -> Maybe Bool Source # | |
| FromPrimitiveAttribute Double Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods fromPrimitiveAttribute :: PrimitiveAttribute -> Maybe Double Source # | |
| FromPrimitiveAttribute Int Source # | |
Defined in OpenTelemetry.Attributes.Attribute Methods fromPrimitiveAttribute :: PrimitiveAttribute -> Maybe Int Source # | |
newtype AttributeKey a Source #
A AttributeKey is a name for an attribute. The type parameter sets the type of the
attribute the key should be associated with. This is useful for standardising
attribute keys, since we can define both the key and the type of value it is
intended to record.
For example, we might define:
-- See https://opentelemetry.io/docs/specs/semconv/attributes-registry/server/ serverPortKey :: AttributeKey Int serverPortKey = "server.port"
Constructors
| AttributeKey | |
Instances
| IsString (AttributeKey a) Source # | Raise an error if the string is empty. | ||||
Defined in OpenTelemetry.Attributes.Key Methods fromString :: String -> AttributeKey a # | |||||
| Generic (AttributeKey a) Source # | |||||
Defined in OpenTelemetry.Attributes.Key Associated Types
Methods from :: AttributeKey a -> Rep (AttributeKey a) x # to :: Rep (AttributeKey a) x -> AttributeKey a # | |||||
| Show (AttributeKey a) Source # | |||||
Defined in OpenTelemetry.Attributes.Key Methods showsPrec :: Int -> AttributeKey a -> ShowS # show :: AttributeKey a -> String # showList :: [AttributeKey a] -> ShowS # | |||||
| Eq (AttributeKey a) Source # | |||||
Defined in OpenTelemetry.Attributes.Key Methods (==) :: AttributeKey a -> AttributeKey a -> Bool # (/=) :: AttributeKey a -> AttributeKey a -> Bool # | |||||
| Ord (AttributeKey a) Source # | |||||
Defined in OpenTelemetry.Attributes.Key Methods compare :: AttributeKey a -> AttributeKey a -> Ordering # (<) :: AttributeKey a -> AttributeKey a -> Bool # (<=) :: AttributeKey a -> AttributeKey a -> Bool # (>) :: AttributeKey a -> AttributeKey a -> Bool # (>=) :: AttributeKey a -> AttributeKey a -> Bool # max :: AttributeKey a -> AttributeKey a -> AttributeKey a # min :: AttributeKey a -> AttributeKey a -> AttributeKey a # | |||||
| type Rep (AttributeKey a) Source # | |||||
Defined in OpenTelemetry.Attributes.Key type Rep (AttributeKey a) = D1 ('MetaData "AttributeKey" "OpenTelemetry.Attributes.Key" "hs-opentelemetry-api-0.3.0.0-6VLKmhDACLT6bB8qCOmjAb" 'True) (C1 ('MetaCons "AttributeKey" 'PrefixI 'True) (S1 ('MetaSel ('Just "unkey") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text))) | |||||
module OpenTelemetry.Attributes.Key
Attribute limits
data AttributeLimits Source #
It is possible when adding attributes that a programming error might cause too many
attributes to be added to an event. Thus, Attributes use the limits set here as a safeguard
against excessive memory consumption.
Constructors
| AttributeLimits | |
Fields
| |
Instances
| Data AttributeLimits Source # | |||||
Defined in OpenTelemetry.Attributes Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> AttributeLimits -> c AttributeLimits # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c AttributeLimits # toConstr :: AttributeLimits -> Constr # dataTypeOf :: AttributeLimits -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c AttributeLimits) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c AttributeLimits) # gmapT :: (forall b. Data b => b -> b) -> AttributeLimits -> AttributeLimits # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> AttributeLimits -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> AttributeLimits -> r # gmapQ :: (forall d. Data d => d -> u) -> AttributeLimits -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> AttributeLimits -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> AttributeLimits -> m AttributeLimits # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> AttributeLimits -> m AttributeLimits # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> AttributeLimits -> m AttributeLimits # | |||||
| Generic AttributeLimits Source # | |||||
Defined in OpenTelemetry.Attributes Associated Types
Methods from :: AttributeLimits -> Rep AttributeLimits x # to :: Rep AttributeLimits x -> AttributeLimits # | |||||
| Read AttributeLimits Source # | |||||
Defined in OpenTelemetry.Attributes Methods readsPrec :: Int -> ReadS AttributeLimits # readList :: ReadS [AttributeLimits] # | |||||
| Show AttributeLimits Source # | |||||
Defined in OpenTelemetry.Attributes Methods showsPrec :: Int -> AttributeLimits -> ShowS # show :: AttributeLimits -> String # showList :: [AttributeLimits] -> ShowS # | |||||
| Eq AttributeLimits Source # | |||||
Defined in OpenTelemetry.Attributes Methods (==) :: AttributeLimits -> AttributeLimits -> Bool # (/=) :: AttributeLimits -> AttributeLimits -> Bool # | |||||
| Ord AttributeLimits Source # | |||||
Defined in OpenTelemetry.Attributes Methods compare :: AttributeLimits -> AttributeLimits -> Ordering # (<) :: AttributeLimits -> AttributeLimits -> Bool # (<=) :: AttributeLimits -> AttributeLimits -> Bool # (>) :: AttributeLimits -> AttributeLimits -> Bool # (>=) :: AttributeLimits -> AttributeLimits -> Bool # max :: AttributeLimits -> AttributeLimits -> AttributeLimits # min :: AttributeLimits -> AttributeLimits -> AttributeLimits # | |||||
| Hashable AttributeLimits Source # | |||||
Defined in OpenTelemetry.Attributes | |||||
| type Rep AttributeLimits Source # | |||||
Defined in OpenTelemetry.Attributes type Rep AttributeLimits = D1 ('MetaData "AttributeLimits" "OpenTelemetry.Attributes" "hs-opentelemetry-api-0.3.0.0-6VLKmhDACLT6bB8qCOmjAb" 'False) (C1 ('MetaCons "AttributeLimits" 'PrefixI 'True) (S1 ('MetaSel ('Just "attributeCountLimit") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 (Maybe Int)) :*: S1 ('MetaSel ('Just "attributeLengthLimit") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 (Maybe Int)))) | |||||
defaultAttributeLimits :: AttributeLimits Source #
Default attribute limits used in the global attribute limit configuration if no environment variables are set.
Values:
attributeCountLimit:Just 128attributeLengthLimit: orNothing
Unsafe utilities
unsafeMergeAttributesIgnoringLimits :: Attributes -> Attributes -> Attributes Source #
Left-biased merge.