| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
OpenTelemetry.Exporter.Metric
Description
Push metric exporter interface (specificationmetricssdk.md, MetricExporter).
Synopsis
- data MetricExporter = MetricExporter {
- metricExporterExport :: !(Vector ResourceMetricsExport -> IO ExportResult)
- metricExporterShutdown :: !(IO ShutdownResult)
- metricExporterForceFlush :: !(IO FlushResult)
- data MetricExport
- = MetricExportSum {
- mesName :: !Text
- mesDescription :: !Text
- mesUnit :: !Text
- mesScope :: !InstrumentationLibrary
- mesMonotonic :: !Bool
- mesIsInt :: !Bool
- mesAggregationTemporality :: !AggregationTemporality
- mesSumPoints :: !(Vector SumDataPoint)
- | MetricExportHistogram {
- mehName :: !Text
- mehDescription :: !Text
- mehUnit :: !Text
- mehScope :: !InstrumentationLibrary
- mehAggregationTemporality :: !AggregationTemporality
- mehPoints :: !(Vector HistogramDataPoint)
- | MetricExportExponentialHistogram { }
- | MetricExportGauge {
- megName :: !Text
- megDescription :: !Text
- megUnit :: !Text
- megScope :: !InstrumentationLibrary
- megIsInt :: !Bool
- megGaugePoints :: !(Vector GaugeDataPoint)
- = MetricExportSum {
- data ResourceMetricsExport = ResourceMetricsExport {}
- data ScopeMetricsExport = ScopeMetricsExport {
- scopeMetricsScope :: !InstrumentationLibrary
- scopeMetricsExports :: !(Vector MetricExport)
- data MetricExporter = MetricExporter {
- metricExporterExport :: !(Vector ResourceMetricsExport -> IO ExportResult)
- metricExporterShutdown :: !(IO ShutdownResult)
- metricExporterForceFlush :: !(IO FlushResult)
- data AggregationTemporality
- data NumberValue
- = IntNumber !Int64
- | DoubleNumber !Double
- data OptionalDouble
- = NoDouble
- | SomeDouble !Double
- toMaybeDouble :: OptionalDouble -> Maybe Double
- data MetricExemplar = MetricExemplar {}
- data SumDataPoint = SumDataPoint {}
- data HistogramDataPoint = HistogramDataPoint {
- histogramDataPointStartTimeUnixNano :: !Word64
- histogramDataPointTimeUnixNano :: !Word64
- histogramDataPointCount :: !Word64
- histogramDataPointSum :: !Double
- histogramDataPointBucketCounts :: !(Vector Word64)
- histogramDataPointExplicitBounds :: !(Vector Double)
- histogramDataPointAttributes :: !Attributes
- histogramDataPointMin :: !(Maybe Double)
- histogramDataPointMax :: !(Maybe Double)
- histogramDataPointExemplars :: !(Vector MetricExemplar)
- data ExponentialHistogramDataPoint = ExponentialHistogramDataPoint {
- exponentialHistogramDataPointStartTimeUnixNano :: !Word64
- exponentialHistogramDataPointTimeUnixNano :: !Word64
- exponentialHistogramDataPointCount :: !Word64
- exponentialHistogramDataPointSum :: !(Maybe Double)
- exponentialHistogramDataPointScale :: !Int32
- exponentialHistogramDataPointZeroCount :: !Word64
- exponentialHistogramDataPointPositiveOffset :: !Int32
- exponentialHistogramDataPointPositiveBucketCounts :: !(Vector Word64)
- exponentialHistogramDataPointNegativeOffset :: !Int32
- exponentialHistogramDataPointNegativeBucketCounts :: !(Vector Word64)
- exponentialHistogramDataPointAttributes :: !Attributes
- exponentialHistogramDataPointMin :: !(Maybe Double)
- exponentialHistogramDataPointMax :: !(Maybe Double)
- exponentialHistogramDataPointExemplars :: !(Vector MetricExemplar)
- exponentialHistogramDataPointZeroThreshold :: !Double
- data GaugeDataPoint = GaugeDataPoint {}
- filterAttributesByKeys :: Maybe (HashSet Text) -> Attributes -> Attributes
- complementAttributesByKeys :: Maybe (HashSet Text) -> Attributes -> Attributes
Documentation
data MetricExporter Source #
Since: 0.0.1.0
Constructors
| MetricExporter | |
Fields
| |
data MetricExport Source #
One exported metric (all points share nameunitdescription/scope).
Since: 0.0.1.0
Constructors
| MetricExportSum | |
Fields
| |
| MetricExportHistogram | |
Fields
| |
| MetricExportExponentialHistogram | |
Fields
| |
| MetricExportGauge | |
Fields
| |
Instances
data ResourceMetricsExport Source #
Since: 0.0.1.0
Constructors
| ResourceMetricsExport | |
Fields | |
Instances
| Generic ResourceMetricsExport Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Associated Types
Methods from :: ResourceMetricsExport -> Rep ResourceMetricsExport x # to :: Rep ResourceMetricsExport x -> ResourceMetricsExport # | |||||
| Show ResourceMetricsExport Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods showsPrec :: Int -> ResourceMetricsExport -> ShowS # show :: ResourceMetricsExport -> String # showList :: [ResourceMetricsExport] -> ShowS # | |||||
| Eq ResourceMetricsExport Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods (==) :: ResourceMetricsExport -> ResourceMetricsExport -> Bool # (/=) :: ResourceMetricsExport -> ResourceMetricsExport -> Bool # | |||||
| type Rep ResourceMetricsExport Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export type Rep ResourceMetricsExport = D1 ('MetaData "ResourceMetricsExport" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "ResourceMetricsExport" 'PrefixI 'True) (S1 ('MetaSel ('Just "resourceMetricsResource") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 MaterializedResources) :*: S1 ('MetaSel ('Just "resourceMetricsScopes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector ScopeMetricsExport)))) | |||||
data ScopeMetricsExport Source #
Since: 0.0.1.0
Constructors
| ScopeMetricsExport | |
Fields
| |
Instances
| Generic ScopeMetricsExport Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Associated Types
Methods from :: ScopeMetricsExport -> Rep ScopeMetricsExport x # to :: Rep ScopeMetricsExport x -> ScopeMetricsExport # | |||||
| Show ScopeMetricsExport Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods showsPrec :: Int -> ScopeMetricsExport -> ShowS # show :: ScopeMetricsExport -> String # showList :: [ScopeMetricsExport] -> ShowS # | |||||
| Eq ScopeMetricsExport Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods (==) :: ScopeMetricsExport -> ScopeMetricsExport -> Bool # (/=) :: ScopeMetricsExport -> ScopeMetricsExport -> Bool # | |||||
| type Rep ScopeMetricsExport Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export type Rep ScopeMetricsExport = D1 ('MetaData "ScopeMetricsExport" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "ScopeMetricsExport" 'PrefixI 'True) (S1 ('MetaSel ('Just "scopeMetricsScope") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 InstrumentationLibrary) :*: S1 ('MetaSel ('Just "scopeMetricsExports") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector MetricExport)))) | |||||
data MetricExporter Source #
Since: 0.0.1.0
Constructors
| MetricExporter | |
Fields
| |
data AggregationTemporality Source #
Export-time aggregation temporality (maps to OTLP AggregationTemporality).
Since: 0.0.1.0
Constructors
| AggregationDelta | |
| AggregationCumulative |
Instances
| Generic AggregationTemporality Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Associated Types
Methods from :: AggregationTemporality -> Rep AggregationTemporality x # to :: Rep AggregationTemporality x -> AggregationTemporality # | |||||
| Show AggregationTemporality Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods showsPrec :: Int -> AggregationTemporality -> ShowS # show :: AggregationTemporality -> String # showList :: [AggregationTemporality] -> ShowS # | |||||
| Eq AggregationTemporality Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods (==) :: AggregationTemporality -> AggregationTemporality -> Bool # (/=) :: AggregationTemporality -> AggregationTemporality -> Bool # | |||||
| type Rep AggregationTemporality Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export type Rep AggregationTemporality = D1 ('MetaData "AggregationTemporality" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "AggregationDelta" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "AggregationCumulative" 'PrefixI 'False) (U1 :: Type -> Type)) | |||||
data NumberValue Source #
A numeric metric value, either integral or floating-point.
Uses UNPACK to avoid the extra indirection that Either Int64 Double incurs.
Since: 0.0.1.0
Constructors
| IntNumber !Int64 | |
| DoubleNumber !Double |
Instances
| Generic NumberValue Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Associated Types
| |||||
| Show NumberValue Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods showsPrec :: Int -> NumberValue -> ShowS # show :: NumberValue -> String # showList :: [NumberValue] -> ShowS # | |||||
| Eq NumberValue Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export | |||||
| type Rep NumberValue Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export type Rep NumberValue = D1 ('MetaData "NumberValue" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "IntNumber" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'SourceUnpack 'SourceStrict 'DecidedStrict) (Rec0 Int64)) :+: C1 ('MetaCons "DoubleNumber" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'SourceUnpack 'SourceStrict 'DecidedStrict) (Rec0 Double))) | |||||
data OptionalDouble Source #
An optional Double, using UNPACK to avoid the extra box that Maybe Double incurs.
2 words for SomeDouble vs 4 for Just (D# x).
Since: 0.0.1.0
Constructors
| NoDouble | |
| SomeDouble !Double |
Instances
| Generic OptionalDouble Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Associated Types
Methods from :: OptionalDouble -> Rep OptionalDouble x # to :: Rep OptionalDouble x -> OptionalDouble # | |||||
| Show OptionalDouble Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods showsPrec :: Int -> OptionalDouble -> ShowS # show :: OptionalDouble -> String # showList :: [OptionalDouble] -> ShowS # | |||||
| Eq OptionalDouble Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods (==) :: OptionalDouble -> OptionalDouble -> Bool # (/=) :: OptionalDouble -> OptionalDouble -> Bool # | |||||
| type Rep OptionalDouble Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export type Rep OptionalDouble = D1 ('MetaData "OptionalDouble" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "NoDouble" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "SomeDouble" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'SourceUnpack 'SourceStrict 'DecidedStrict) (Rec0 Double))) | |||||
toMaybeDouble :: OptionalDouble -> Maybe Double Source #
Convert to the standard Maybe Double (e.g. for OTLP export).
Since: 0.0.1.0
data MetricExemplar Source #
Exemplar (trace link + optional measurement) for OTLP Exemplar.
Since: 0.0.1.0
Constructors
| MetricExemplar | |
Instances
| Generic MetricExemplar Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Associated Types
Methods from :: MetricExemplar -> Rep MetricExemplar x # to :: Rep MetricExemplar x -> MetricExemplar # | |||||
| Show MetricExemplar Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods showsPrec :: Int -> MetricExemplar -> ShowS # show :: MetricExemplar -> String # showList :: [MetricExemplar] -> ShowS # | |||||
| Eq MetricExemplar Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods (==) :: MetricExemplar -> MetricExemplar -> Bool # (/=) :: MetricExemplar -> MetricExemplar -> Bool # | |||||
| type Rep MetricExemplar Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export type Rep MetricExemplar = D1 ('MetaData "MetricExemplar" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "MetricExemplar" 'PrefixI 'True) ((S1 ('MetaSel ('Just "metricExemplarTraceId") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 ByteString) :*: S1 ('MetaSel ('Just "metricExemplarSpanId") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 ByteString)) :*: (S1 ('MetaSel ('Just "metricExemplarTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: (S1 ('MetaSel ('Just "metricExemplarFilteredAttributes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Attributes) :*: S1 ('MetaSel ('Just "metricExemplarValue") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe NumberValue)))))) | |||||
data SumDataPoint Source #
One sum data point (cumulative or delta depending on reader temporality in SDK).
Since: 0.0.1.0
Constructors
| SumDataPoint | |
Fields | |
Instances
| Generic SumDataPoint Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Associated Types
| |||||
| Show SumDataPoint Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods showsPrec :: Int -> SumDataPoint -> ShowS # show :: SumDataPoint -> String # showList :: [SumDataPoint] -> ShowS # | |||||
| Eq SumDataPoint Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export | |||||
| type Rep SumDataPoint Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export type Rep SumDataPoint = D1 ('MetaData "SumDataPoint" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "SumDataPoint" 'PrefixI 'True) ((S1 ('MetaSel ('Just "sumDataPointStartTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: S1 ('MetaSel ('Just "sumDataPointTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64)) :*: (S1 ('MetaSel ('Just "sumDataPointValue") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 NumberValue) :*: (S1 ('MetaSel ('Just "sumDataPointAttributes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Attributes) :*: S1 ('MetaSel ('Just "sumDataPointExemplars") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector MetricExemplar)))))) | |||||
data HistogramDataPoint Source #
Histogram bucket counts (explicit boundaries) + sum + count.
Since: 0.0.1.0
Constructors
| HistogramDataPoint | |
Fields
| |
Instances
| Generic HistogramDataPoint Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Associated Types
Methods from :: HistogramDataPoint -> Rep HistogramDataPoint x # to :: Rep HistogramDataPoint x -> HistogramDataPoint # | |||||
| Show HistogramDataPoint Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods showsPrec :: Int -> HistogramDataPoint -> ShowS # show :: HistogramDataPoint -> String # showList :: [HistogramDataPoint] -> ShowS # | |||||
| Eq HistogramDataPoint Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods (==) :: HistogramDataPoint -> HistogramDataPoint -> Bool # (/=) :: HistogramDataPoint -> HistogramDataPoint -> Bool # | |||||
| type Rep HistogramDataPoint Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export type Rep HistogramDataPoint = D1 ('MetaData "HistogramDataPoint" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "HistogramDataPoint" 'PrefixI 'True) (((S1 ('MetaSel ('Just "histogramDataPointStartTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: S1 ('MetaSel ('Just "histogramDataPointTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64)) :*: (S1 ('MetaSel ('Just "histogramDataPointCount") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: (S1 ('MetaSel ('Just "histogramDataPointSum") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Double) :*: S1 ('MetaSel ('Just "histogramDataPointBucketCounts") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector Word64))))) :*: ((S1 ('MetaSel ('Just "histogramDataPointExplicitBounds") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector Double)) :*: S1 ('MetaSel ('Just "histogramDataPointAttributes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Attributes)) :*: (S1 ('MetaSel ('Just "histogramDataPointMin") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Double)) :*: (S1 ('MetaSel ('Just "histogramDataPointMax") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Double)) :*: S1 ('MetaSel ('Just "histogramDataPointExemplars") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector MetricExemplar))))))) | |||||
data ExponentialHistogramDataPoint Source #
Exponential histogram data point (OTLP native exponential layout).
Since: 0.0.1.0
Constructors
| ExponentialHistogramDataPoint | |
Fields
| |
Instances
| Generic ExponentialHistogramDataPoint Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Associated Types
| |||||
| Show ExponentialHistogramDataPoint Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods showsPrec :: Int -> ExponentialHistogramDataPoint -> ShowS # show :: ExponentialHistogramDataPoint -> String # showList :: [ExponentialHistogramDataPoint] -> ShowS # | |||||
| Eq ExponentialHistogramDataPoint Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export | |||||
| type Rep ExponentialHistogramDataPoint Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export type Rep ExponentialHistogramDataPoint = D1 ('MetaData "ExponentialHistogramDataPoint" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "ExponentialHistogramDataPoint" 'PrefixI 'True) (((S1 ('MetaSel ('Just "exponentialHistogramDataPointStartTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: (S1 ('MetaSel ('Just "exponentialHistogramDataPointTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointCount") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64))) :*: ((S1 ('MetaSel ('Just "exponentialHistogramDataPointSum") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Double)) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointScale") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Int32)) :*: (S1 ('MetaSel ('Just "exponentialHistogramDataPointZeroCount") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointPositiveOffset") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Int32)))) :*: (((S1 ('MetaSel ('Just "exponentialHistogramDataPointPositiveBucketCounts") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector Word64)) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointNegativeOffset") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Int32)) :*: (S1 ('MetaSel ('Just "exponentialHistogramDataPointNegativeBucketCounts") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector Word64)) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointAttributes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Attributes))) :*: ((S1 ('MetaSel ('Just "exponentialHistogramDataPointMin") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Double)) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointMax") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Double))) :*: (S1 ('MetaSel ('Just "exponentialHistogramDataPointExemplars") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector MetricExemplar)) :*: S1 ('MetaSel ('Just "exponentialHistogramDataPointZeroThreshold") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Double)))))) | |||||
data GaugeDataPoint Source #
Last-value gauge point.
Since: 0.0.1.0
Constructors
| GaugeDataPoint | |
Fields | |
Instances
| Generic GaugeDataPoint Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Associated Types
Methods from :: GaugeDataPoint -> Rep GaugeDataPoint x # to :: Rep GaugeDataPoint x -> GaugeDataPoint # | |||||
| Show GaugeDataPoint Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods showsPrec :: Int -> GaugeDataPoint -> ShowS # show :: GaugeDataPoint -> String # showList :: [GaugeDataPoint] -> ShowS # | |||||
| Eq GaugeDataPoint Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export Methods (==) :: GaugeDataPoint -> GaugeDataPoint -> Bool # (/=) :: GaugeDataPoint -> GaugeDataPoint -> Bool # | |||||
| type Rep GaugeDataPoint Source # | |||||
Defined in OpenTelemetry.Internal.Metric.Export type Rep GaugeDataPoint = D1 ('MetaData "GaugeDataPoint" "OpenTelemetry.Internal.Metric.Export" "hs-opentelemetry-api-1.0.0.0-inplace" 'False) (C1 ('MetaCons "GaugeDataPoint" 'PrefixI 'True) ((S1 ('MetaSel ('Just "gaugeDataPointStartTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64) :*: S1 ('MetaSel ('Just "gaugeDataPointTimeUnixNano") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word64)) :*: (S1 ('MetaSel ('Just "gaugeDataPointValue") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 NumberValue) :*: (S1 ('MetaSel ('Just "gaugeDataPointAttributes") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Attributes) :*: S1 ('MetaSel ('Just "gaugeDataPointExemplars") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Vector MetricExemplar)))))) | |||||
filterAttributesByKeys :: Maybe (HashSet Text) -> Attributes -> Attributes Source #
When a view selects attribute keys, drop other keys at export time (series identity unchanged).
The HashSet should be pre-built at instrument creation time so that
this function avoids allocating a new set on every data point.
Since: 0.0.1.0
complementAttributesByKeys :: Maybe (HashSet Text) -> Attributes -> Attributes Source #
Complement of filterAttributesByKeys: returns attributes whose keys
are NOT in the export set. Used for exemplar filtered_attributes per spec
 metrics/sdk.md Exemplar: "the set of attributes that were filtered out
by the aggregator".
The HashSet should be pre-built at instrument creation time so that
this function avoids allocating a new set on every data point.
Since: 0.0.1.0