| Stability | experimental |
|---|---|
| Safe Haskell | None |
| Language | Haskell2010 |
OpenTelemetry.Processor.LogRecord
Description
Synopsis
- data LogRecordProcessor = LogRecordProcessor {}
- data ShutdownResult
- data FlushResult
Documentation
data LogRecordProcessor Source #
Receives callbacks when log records are emitted. Built-in processors batch log records and pass them to exporters.
Spec: https://opentelemetry.io/docs/specs/otel/logs/sdk/#logrecordprocessor
Since: 0.0.1.0
Constructors
| LogRecordProcessor | |
Fields
| |
data ShutdownResult Source #
Since: 0.0.1.0
Constructors
| ShutdownSuccess | |
| ShutdownFailure | |
| ShutdownTimeout |
Instances
| Show ShutdownResult Source # | |
Defined in OpenTelemetry.Internal.Common.Types Methods showsPrec :: Int -> ShutdownResult -> ShowS # show :: ShutdownResult -> String # showList :: [ShutdownResult] -> ShowS # | |
| Eq ShutdownResult Source # | |
Defined in OpenTelemetry.Internal.Common.Types Methods (==) :: ShutdownResult -> ShutdownResult -> Bool # (/=) :: ShutdownResult -> ShutdownResult -> Bool # | |
data FlushResult Source #
The outcome of a call to OpenTelemetry.Trace.forceFlush or OpenTelemetry.Log.forceFlush
Since: 0.0.1.0
Constructors
| FlushTimeout | One or more spans or |
| FlushSuccess | Flushing spans or |
| FlushError | One or more exporters failed to successfully export one or more
unexported spans or |
Instances
| Show FlushResult Source # | |
Defined in OpenTelemetry.Internal.Common.Types Methods showsPrec :: Int -> FlushResult -> ShowS # show :: FlushResult -> String # showList :: [FlushResult] -> ShowS # | |
| Eq FlushResult Source # | |
Defined in OpenTelemetry.Internal.Common.Types | |