| Copyright | (c) Ian Duncan 2021 |
|---|---|
| License | BSD-3 |
| Maintainer | Ian Duncan |
| Stability | experimental |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
OpenTelemetry.Processor.Span
Description
Span processor is an interface which allows hooks for span start and end method invocations. The span processors are invoked only when IsRecording is true.
Built-in span processors are responsible for batching and conversion of spans to exportable representation and passing batches to exporters.
Span processors can be registered directly on SDK TracerProvider and they are invoked in the same order as they were registered.
Each processor registered on TracerProvider is a start of pipeline that consist of span processor and optional exporter. SDK MUST allow to end each pipeline with individual exporter.
SDK MUST allow users to implement and configure custom processors and decorate built-in processors for advanced scenarios such as tagging or filtering.
Synopsis
- data SpanProcessor = SpanProcessor {}
- data FlushResult
- data ShutdownResult
Documentation
data SpanProcessor Source #
Span processors receive callbacks on span start and end.
Spec: https://opentelemetry.io/docs/specs/otel/trace/sdk/#span-processor
Since: 0.0.1.0
Constructors
| SpanProcessor | |
Fields
| |
data FlushResult Source #
The outcome of a call to OpenTelemetry.Trace.forceFlush or OpenTelemetry.Log.forceFlush
Since: 0.0.1.0
Constructors
| FlushTimeout | One or more spans or |
| FlushSuccess | Flushing spans or |
| FlushError | One or more exporters failed to successfully export one or more
unexported spans or |
Instances
| Show FlushResult Source # | |
Defined in OpenTelemetry.Internal.Common.Types Methods showsPrec :: Int -> FlushResult -> ShowS # show :: FlushResult -> String # showList :: [FlushResult] -> ShowS # | |
| Eq FlushResult Source # | |
Defined in OpenTelemetry.Internal.Common.Types | |
data ShutdownResult Source #
Since: 0.0.1.0
Constructors
| ShutdownSuccess | |
| ShutdownFailure | |
| ShutdownTimeout |
Instances
| Show ShutdownResult Source # | |
Defined in OpenTelemetry.Internal.Common.Types Methods showsPrec :: Int -> ShutdownResult -> ShowS # show :: ShutdownResult -> String # showList :: [ShutdownResult] -> ShowS # | |
| Eq ShutdownResult Source # | |
Defined in OpenTelemetry.Internal.Common.Types Methods (==) :: ShutdownResult -> ShutdownResult -> Bool # (/=) :: ShutdownResult -> ShutdownResult -> Bool # | |