| Copyright | (c) Ian Duncan 2021 |
|---|---|
| License | BSD-3 |
| Maintainer | Ian Duncan |
| Stability | experimental |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
OpenTelemetry.Resource.Kubernetes
Description
Synopsis
- data Cluster = Cluster {
- clusterName :: Maybe Text
- clusterUid :: Maybe Text
- data Node = Node {}
- newtype Namespace = Namespace {}
- data Pod = Pod {}
- data Container = Container {}
- data ReplicaSet = ReplicaSet {}
- data Deployment = Deployment {}
- data StatefulSet = StatefulSet {}
- data DaemonSet = DaemonSet {}
- data Job = Job {}
- data CronJob = CronJob {
- cronJobUid :: Maybe Text
- cronJobName :: Maybe Text
Documentation
A Kubernetes Cluster.
Since: 0.0.1.0
Constructors
| Cluster | |
Fields
| |
Instances
A Kubernetes Node.
Since: 0.0.1.0
Namespaces provide a scope for names. Names of objects need to be unique within a namespace, but not across namespaces.
Since: 0.0.1.0
Constructors
| Namespace | |
Fields
| |
Instances
| Show Namespace Source # | |
| ToResource Namespace Source # | |
Defined in OpenTelemetry.Resource.Kubernetes Methods toResource :: Namespace -> Resource Source # | |
The smallest and simplest Kubernetes object. A Pod represents a set of running containers on your cluster.
Since: 0.0.1.0
Constructors
| Pod | |
A container in a PodTemplate.
Since: 0.0.1.0
Constructors
| Container | |
Fields
| |
Instances
| ToResource Container Source # | |
Defined in OpenTelemetry.Resource.Kubernetes Methods toResource :: Container -> Resource Source # | |
data ReplicaSet Source #
A ReplicaSet’s purpose is to maintain a stable set of replica Pods running at any given time.
Since: 0.0.1.0
Constructors
| ReplicaSet | |
Fields | |
Instances
| ToResource ReplicaSet Source # | |
Defined in OpenTelemetry.Resource.Kubernetes Methods toResource :: ReplicaSet -> Resource Source # | |
data Deployment Source #
An API object that manages a replicated application, typically by running Pods with no local state. Each replica is represented by a Pod, and the Pods are distributed among the nodes of a cluster.
Since: 0.0.1.0
Constructors
| Deployment | |
Fields
| |
Instances
| ToResource Deployment Source # | |
Defined in OpenTelemetry.Resource.Kubernetes Methods toResource :: Deployment -> Resource Source # | |
data StatefulSet Source #
Manages the deployment and scaling of a set of Pods, and provides guarantees about the ordering and uniqueness of these Pods.
Since: 0.0.1.0
Constructors
| StatefulSet | |
Fields
| |
Instances
| ToResource StatefulSet Source # | |
Defined in OpenTelemetry.Resource.Kubernetes Methods toResource :: StatefulSet -> Resource Source # | |
A DaemonSet ensures that all (or some) Nodes run a copy of a Pod.
Since: 0.0.1.0
Constructors
| DaemonSet | |
Fields
| |
Instances
| ToResource DaemonSet Source # | |
Defined in OpenTelemetry.Resource.Kubernetes Methods toResource :: DaemonSet -> Resource Source # | |
A Job creates one or more Pods and ensures that a specified number of them successfully terminate.
Since: 0.0.1.0
Constructors
| Job | |
Instances
| ToResource Job Source # | |
Defined in OpenTelemetry.Resource.Kubernetes Methods toResource :: Job -> Resource Source # | |
A CronJob creates Jobs on a repeating schedule.
Since: 0.0.1.0
Constructors
| CronJob | |
Fields
| |
Instances
| ToResource CronJob Source # | |
Defined in OpenTelemetry.Resource.Kubernetes Methods toResource :: CronJob -> Resource Source # | |